@@ -112,7 +112,7 @@ static QStringList getSelectedCategoriesFromCategoriesView(AutoCheckTreeWidget *
     QTreeWidgetItemIterator it(categoriesView, QTreeWidgetItemIterator::Checked);
     while (*it) {
         QStringList path = categoriesView->pathByItem(*it++);
-        if (path.count()) {
+        if (!path.isEmpty()) {
             path.replaceInStrings(CategoryConfig::categorySeparator, QLatin1Char('\\')
                                   +CategoryConfig::categorySeparator);
             categories.append(path.join(CategoryConfig::categorySeparator));
